========
Examples
========

This folder contains example experiment modules, which each showcase some feature of the package.

The following list provides a short introduction into the topics discussed in each example:

- ``02_saving_models.py``: Saving a trained model to a persistent representation on the hard disk
- ``03_loading_models.py``: How a previously saved model can be loaded from the hard disk. ALSO: explains
  how multiple MEGAN predictions and explanations can be visualized in a single PDF document with multiple
  pages.
- ``04_counterfactuals.py``: The generation of counterfactual explanations with the ``vgd_counterfactuals``
  library.